@@ -20,10 +20,14 @@ def create_app() -> Flask:
     """
     Creates a flask application and registers the api blueprint.
     """
-    log.debug("Initializing app")
+    log.debug("Initializing app.")
 
     app = Flask(__name__)
-    app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1, x_host=1)  # type: ignore
+    app.wsgi_app = ProxyFix(  # type: ignore
+        app.wsgi_app,
+        x_proto=int(settings.use_x_forwarded_proto),
+        x_host=int(settings.use_x_forwarded_host),
+    )
 
     app.config.update(
         SECRET_KEY=settings.secret_key,
@@ -46,9 +50,9 @@ def create_app() -> Flask:
 
     app.register_blueprint(api)
 
-    log.debug("Migrating database")
+    log.debug("Migrating database.")
     run_migrations.main()
 
-    log.debug("App initialisation complete")
+    log.debug("App initialisation complete.")
 
     return app
